@@ -1,36 +1,68 @@
 // TODO: use tokio?
-use clap::{AppSettings, Clap};
+use clap::Parser;
 use rsexp::Sexp;
 use tracing::{event, Level};
 
-#[derive(Clap)]
+#[derive(Parser)]
 #[clap(version = "1.0", author = "Laurent Mazare <lmazare@gmail.com>")]
-#[clap(setting = AppSettings::ColoredHelp)]
 struct Opts {
     #[clap(subcommand)]
     subcmd: SubCommand,
 }
 
-#[derive(Clap)]
+#[derive(Parser)]
 enum SubCommand {
+    /// Run some benchmark converting repeatedly an in-memory sexp string to and
+    /// from a sexp object.
     Bench(Bench),
+    /// Read a sexp and print it back.
+    Print(Print),
 }
 
-#[derive(Clap)]
+#[derive(Parser)]
 struct Bench {
+    /// The sexp file to use as input.
     #[clap(short, long)]
     input_filename: String,
 
+    /// When specified, write
     #[clap(short, long)]
     output_filename: Option<String>,
 
+    /// The number of times to run the to and of sexp conversions.
     #[clap(long, default_value = "1")]
     iterations: u32,
 
+    /// Verbose mode.
     #[clap(short)]
     verbose: bool,
 }
 
+#[derive(Parser)]
+struct Print {
+    /// The sexp file to use as input.
+    #[clap(short, long)]
+    input_filename: String,
+
+    /// When set, print the machine readable version rather than the human readable one.
+    #[clap(short, long)]
+    mach: bool,
+}
+
+impl Print {
+    fn run(&self) -> std::io::Result<()> {
+        let contents = std::fs::read(&self.input_filename)?;
+        let sexp = rsexp::from_slice(&contents).unwrap();
+        if self.mach {
+            sexp.write_mach(&mut std::io::stdout())?;
+        } else {
+            sexp.write_hum(&mut std::io::stdout())?;
+        }
+        println!("");
+        Ok(())
+    }
+}
+
 fn cnt_loop(s: &Sexp) -> (usize, usize) {
     match s {
         Sexp::Atom(atom) => (1, atom.len()),
@@ -87,6 +119,7 @@ fn main() -> std::io::Result<()> {
 
     match opts.subcmd {
         SubCommand::Bench(bench) => bench.run()?,
+        SubCommand::Print(print) => print.run()?,
     };
     Ok(())
 }
